pub struct SourceNode<OUTPUT: WriteChannelTrait + 'static> {
pub id: String,
pub write_channel: TypedWriteChannel<OUTPUT>,
pub handler: Box<dyn SourceProcessor<OUTPUT = OUTPUT>>,
}Expand description
Source node structure. It is able to emit data without any input. The graph calls this node any time it’s not processing anything. Users must do their own frame rate control inside this method.
Fields
id: Stringwrite_channel: TypedWriteChannel<OUTPUT>handler: Box<dyn SourceProcessor<OUTPUT = OUTPUT>>Implementations
Sourceimpl<OUTPUT: WriteChannelTrait + 'static> SourceNode<OUTPUT>
impl<OUTPUT: WriteChannelTrait + 'static> SourceNode<OUTPUT>
Sourcepub fn create(
id: String,
processor: Box<dyn SourceProcessor<OUTPUT = OUTPUT>>,
writer_channel: OUTPUT,
) -> SourceNode<OUTPUT>
pub fn create( id: String, processor: Box<dyn SourceProcessor<OUTPUT = OUTPUT>>, writer_channel: OUTPUT, ) -> SourceNode<OUTPUT>
Create a new SourceNode
- Arguments
id- Id of the node. It must be unique in the graph.processor- A boxed instance of the processor that handles the data packets.write_channel- A WriteChannel object for output data.
Sourcepub fn create_common(
id: String,
processor: Box<dyn SourceProcessor<OUTPUT = OUTPUT>>,
) -> Self
pub fn create_common( id: String, processor: Box<dyn SourceProcessor<OUTPUT = OUTPUT>>, ) -> Self
A helper method for creating a SourceNode with the most common parameters instead of manually passing a ReadChannel.
- Arguments
id- Id of the node. It must be unique in the graph.processor- A boxed instance of the processor that handles the data packets.